package Daje::Generate::Templates;
use Mojo::Base -base;

our $VERSION = "0.01";



1;
__END__

=encoding utf-8

=head1 NAME

Daje::Templates - It's new $module

=head1 SYNOPSIS

    use Daje::Templates;

=head1 DESCRIPTION

Daje::Templates is ...

=head1 LICENSE

Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

janeskil1525 E<lt>janeskil1525@gmail.comE<gt>

=cut

